@@ -8,7 +8,7 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
-func TestGetDefaultLogContainer(t *testing.T) {
+func TestGetDefaultContainer(t *testing.T) {
 	uu := map[string]struct {
 		po            *v1.Pod
 		wantContainer string
@@ -26,7 +26,7 @@ func TestGetDefaultLogContainer(t *testing.T) {
 		"container_not_present": {
 			po: &v1.Pod{
 				ObjectMeta: metav1.ObjectMeta{
-					Annotations: map[string]string{"kubectl.kubernetes.io/default-logs-container": "container1"},
+					Annotations: map[string]string{"kubectl.kubernetes.io/default-container": "container1"},
 				},
 			},
 			wantContainer: "",
@@ -35,7 +35,7 @@ func TestGetDefaultLogContainer(t *testing.T) {
 		"container_found": {
 			po: &v1.Pod{
 				ObjectMeta: metav1.ObjectMeta{
-					Annotations: map[string]string{"kubectl.kubernetes.io/default-logs-container": "container1"},
+					Annotations: map[string]string{"kubectl.kubernetes.io/default-container": "container1"},
 				},
 				Spec: v1.PodSpec{
 					Containers: []v1.Container{{Name: "container1"}},
@@ -48,7 +48,7 @@ func TestGetDefaultLogContainer(t *testing.T) {
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
-			container, ok := GetDefaultLogContainer(u.po.ObjectMeta, u.po.Spec)
+			container, ok := GetDefaultContainer(u.po.ObjectMeta, u.po.Spec)
 			assert.Equal(t, u.wantContainer, container)
 			assert.Equal(t, u.wantOk, ok)
 		})
