@@ -4,6 +4,7 @@ import (
 	"context"
 	"time"
 
+	"github.com/derailed/k9s/internal/dao"
 	"github.com/derailed/k9s/internal/model"
 	"github.com/derailed/k9s/internal/render"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -78,5 +79,5 @@ type Tabular interface {
 	RemoveListener(model.TableListener)
 
 	// Delete a resource.
-	Delete(ctx context.Context, path string, propagation *metav1.DeletionPropagation, force bool) error
+	Delete(context.Context, string, *metav1.DeletionPropagation, dao.Grace) error
 }
