@@ -1,6 +1,7 @@
 package view
 
 import (
+	"errors"
 	"fmt"
 	"strings"
 
@@ -101,7 +102,7 @@ func pluginActions(r Runner, aa ui.KeyActions) {
 		}
 		_, ok := aa[key]
 		if ok {
-			log.Warn().Err(fmt.Errorf("Doh! you are trying to override an existing command `%s", k)).Msg("Invalid shortcut")
+			log.Warn().Msgf("Invalid shortcut. You are trying to override an existing command `%s", k)
 			continue
 		}
 		aa[key] = ui.NewKeyAction(
@@ -139,11 +140,20 @@ func pluginAction(r Runner, p config.Plugin) ui.ActionHandler {
 				pipes:      p.Pipes,
 				args:       args,
 			}
-			if run(r.App(), opts) {
-				r.App().Flash().Info("Plugin command launched successfully!")
+			suspend, errChan := run(r.App(), opts)
+			if !suspend {
+				r.App().Flash().Info("Plugin command failed!")
 				return
 			}
-			r.App().Flash().Info("Plugin command failed!")
+			var errs error
+			for e := range errChan {
+				errs = errors.Join(errs, e)
+			}
+			if errs != nil {
+				r.App().cowCmd(errs.Error())
+				return
+			}
+			r.App().Flash().Info("Plugin command launched successfully!")
 		}
 		if p.Confirm {
 			msg := fmt.Sprintf("Run?\n%s %s", p.Command, strings.Join(args, " "))
