@@ -6,7 +6,7 @@ import (
 	"github.com/derailed/k9s/internal"
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/ui"
-	"github.com/gdamore/tcell/v2"
+	"github.com/derailed/tcell/v2"
 )
 
 // Group presents a RBAC group viewer.
@@ -40,7 +40,7 @@ func (g *Group) policyCmd(evt *tcell.EventKey) *tcell.EventKey {
 	if path == "" {
 		return evt
 	}
-	if err := g.App().inject(NewPolicy(g.App(), "Group", path)); err != nil {
+	if err := g.App().inject(NewPolicy(g.App(), "Group", path), false); err != nil {
 		g.App().Flash().Err(err)
 	}
 
